@@ -61,7 +61,7 @@ def initialize():
     #     f.write(creds_json)
     #     print(f"Netsuite Credentials written to: {api_settings.CREDENTIALS_PATH}")
 
-    print("Getting Access Token....")
+    print("\n Generating Access Token....\n")
     netsuite = Netsuite()
     netsuite.request_access_token()
 
@@ -162,13 +162,7 @@ def generate_netsuite_client_config():
     # client_secret = prompt("What is your client secret?", hide_input=True)
     # redirect_url = prompt("Redirect URL", default=api_settings.REDIRECT_URL)
     netsuite_app_name = prompt("What is the netsuite application name (Portion before app.netsuite.com)?", hide_input=False)
-    print('\n')
-    app_name = prompt("App Name", default=api_settings.APP_NAME)
-    print('\n')
-    allow_none = prompt("Allow None", default=api_settings.ALLOW_NONE)
-    print('\n')
-    use_datetime = prompt("Use Datetime", default=api_settings.USE_DATETIME)
-    print('\n')
+    app_name = prompt("App Name (for token storage)", default=api_settings.APP_NAME)
     storage_class = prompt("Storage Class", default=api_settings.defaults.get('STORAGE_CLASS'),
                            type=click.Choice(api_settings.defaults.get('DEFAULT_STORAGE_CLASSES')),
                            show_choices=True)
@@ -181,8 +175,8 @@ def generate_netsuite_client_config():
         # 'REDIRECT_URL': redirect_url,
         'NETSUITE_APP_NAME': netsuite_app_name,
         'APP_NAME': app_name,
-        'ALLOW_NONE': allow_none,
-        'USE_DATETIME': use_datetime,
+        'ALLOW_NONE': api_settings.ALLOW_NONE,
+        'USE_DATETIME': api_settings.USE_DATETIME,
         'STORAGE_CLASS': storage_class,
     }
 
@@ -190,13 +184,12 @@ def generate_netsuite_client_config():
         creds['JSON_STORAGE_PATH'] = prompt("Token Storage File", default=api_settings.JSON_STORAGE_PATH,
                                             type=click.Path(readable=True, writable=True))
 
-    save_to_file = prompt("Save settings to file?", default='y', type=click.BOOL, show_choices=True)
 
-    print("\n ----- Configuration Generated -----")
     with open(api_settings.CREDENTIALS_PATH, 'w') as f:
         creds_json = json.dumps(creds, indent=4)
         f.write(creds_json)
         print(f" Netsuite Credentials path: {api_settings.CREDENTIALS_PATH} ")
+    print("\n ----- Configuration Generated -----")
 
 
 
@@ -207,15 +200,15 @@ def generate_rest_client():
     generate_netsuite_rest_client()
 
 def generate_netsuite_rest_client():
-    print ("--- Rest Client Generator --- \n")
+    print (" ----- Rest Client Generator -----")
     netsuite = Netsuite()
     display_ns_classes = prompt("List available Netsuite Records?", type=click.BOOL, default=True)
     print("")
     records = netsuite.get_netsuite_recordtypes()
     if display_ns_classes:
         display_custom = prompt("Display Custom records (probably not)?", type=click.BOOL, default=False)
-        print("\nRECORDS")
-        print("-----------------")
+        print("\n   RECORDS")
+        print("-------------------")
         if display_custom:
             for record in records:
                 print(record)
@@ -224,7 +217,7 @@ def generate_netsuite_rest_client():
                 if "customrecord" not in record and "customlist" not in record:
                     print(record)
 
-
+    print("\n")
     add_more_records = True
     ns_records_to_include = []
     while add_more_records:
@@ -235,20 +228,21 @@ def generate_netsuite_rest_client():
             print("record already included.")
         else:
             ns_records_to_include.append(next_record)
-        add_more_records = prompt("Add another?", type=click.BOOL, default=True)
+            print(f"Record Added: {next_record}")
+        add_more_records = prompt("Add another?", type=click.BOOL, default='yes', show_choices=True)
 
 
     if len(ns_records_to_include) >> 0:
         record_str = ''
+        index = 0
         for record in ns_records_to_include:
-            record_str += f',{record}'
+            if index == 0:
+                record_str += f'{record}'
+            else:
+                record_str += f',{record}'
     else:
         record_str = 'customer'
 
-
-    # ns_records_to_include = prompt("Which records will you be using (comma separated list, no spaces)", type=click.STRING, default="customer")
-        # print(netsuite.get_netsuite_recordtypes())
-    print(record_str)
     netsuite.generate_rest_client(record_types=record_str)
 
 
